Learn R Programming

TimeSeries.OBeu (version 1.2.4)

ts.non.seas.decomp: Non seasonal decomposition

Description

Decomposition of time series with no seasonal component using local regression models

Usage

ts.non.seas.decomp(tsdata, tojson = FALSE)

Arguments

tsdata

The input univariate non seasonal time series data

tojson

If TRUE the results are returned in json format, default returns a list

Value

A list with the following components:

  • stl.plot:

    • trend The estimated trend component

    • trend.ci.up The estimated up limit for trend component

    • trend.ci.low The estimated low limit for trend component

    • seasonal The estimated seasonal component

    • remainder The estimated remainder component

    • time The time of the series was sampled

  • stl.general:

    • stl.degree The degree of fit

    • degfr The effective degrees of freedom

    • degfr.fitted The fitted degrees of freedom

  • residuals_fitted:

    • residuals The residuals of the model (fitted innovations)

    • fitted The model's fitted values

    • time the time of tsdata

    • line The y=0 line

  • compare:

    • resid.variance The residuals variance

    • used.obs The used observations for the fitting

    • loglik The maximized log-likelihood (of the differenced data), or the approximation to it used

    • aic The AIC value corresponding to the log-likelihood

    • bic The BIC value corresponding to the log-likelihood

    • gcv The generalized cross-validation statistic

Details

For non-seasonal time series there is no seasonal component. Local regression and likelihood models (locfit package) are used in order to extract the trend and remaider components.

See Also

ts.analysis, locfit, predict.locfit

Examples

Run this code
# NOT RUN {
ts.non.seas.decomp(Athens_draft_ts)

# }

Run the code above in your browser using DataLab